@@ -148,7 +148,7 @@ class AMIEClient(object):
         if r.status_code > 200:
             message = response.get('message', 'Server did not provide an error message')
             raise AMIERequestError(message, response=r)
-        return Packet.from_dict(response)
+        return Packet.from_dict(response['result'])
 
     def list_packets(self, *, trans_rec_ids=None, outgoing=None,
                      update_time_start=None, update_time_until=None,
@@ -271,7 +271,6 @@ class AMIEClient(object):
             message = response.get('message', 'Server did not provide an error message')
             raise AMIERequestError(message, response=r)
         return r
-        pass
 
     def set_packet_client_json(self, packet_or_id, client_json):
         """
@@ -297,7 +296,7 @@ class AMIEClient(object):
             # serializes back properly when we do the PUT
             client_json = json.loads(client_json)
 
-        r = self._session.put(url, data=client_json)
+        r = self._session.put(url, json=client_json)
         response = r.json()
         if r.status_code > 200:
             message = response.get('message', 'Server did not provide an error message')
